/*******************************************************************************
* File Name: main_cm0p.c
*
* Version: 1.10
*
* Description: This file provides the source code for smartlock application (App0)
*              running on the Core M0 (Core0).
*
********************************************************************************
* \copyright
* Copyright 2016-2018, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/
#include "project.h"
#include "ble_app.h"
#include "ble_common.h"

/* This is placed in signature section to validate application */
CY_SECTION(".cy_app_signature") __USED const uint32_t cy_bootload_appSignature;

/* BLE FPMM command received buffer */
static fpmm_command_buf_t ble_fpmm_cmd_buf;

/* Local function declarations */
void ble_fpmm_command_callback(uint32_t len, void *cmd);
static void InitBle(void);
static void BleSend(uint32_t size, uint8_t *pBuff);


/*******************************************************************************
* Function Name: main
********************************************************************************
*
* Summary:
*  Main function of App2 Core0.
*
* Parameters:
*  None
* 
* Return:
*  None
*
*******************************************************************************/
int main(void)
{
    Cy_GPIO_Write(Audio_Shutdown_PORT, Audio_Shutdown_NUM, 0);
    Cy_GPIO_Write(NFC_PowerDown_PORT, NFC_PowerDown_NUM, 0);
    Cy_GPIO_Write(VCC_PowerDown_PORT, VCC_PowerDown_NUM, 1);
    
    __enable_irq(); /* Enable global interrupts. */
    
    /* Enable CM4 with the CM4 start address defined in the DFU SDK linker script */
    Cy_SysEnableCM4( (uint32_t)(&__cy_app_core1_start_addr) );
    
    /* Interrupt vector must be manually set in profile only mode */
    Cy_SysInt_SetVector(BLE_bless_isr_cfg.intrSrc, &Cy_BLE_BlessInterrupt);
    
    /* Initializes the BLE application. */
    InitBle();
    
    for(;;)
    {
        ble_app_task();
        if(ble_fpmm_cmd_buf.receive_flag)
        {
            ble_fpmm_cmd_buf.receive_flag = false;
            BleSend(ble_fpmm_cmd_buf.len, ble_fpmm_cmd_buf.buf);
        }
    }
}

/*******************************************************************************
* Function Name: ble_fpmm_command_callback
****************************************************************************//**
*
* \brief The callback function handler for BLE FPMM command receivced
*
* \param len  Received len
*
* \param cmd  point to the data buffer
*
* \return None
*
*******************************************************************************/
void ble_fpmm_command_callback(uint32_t len, void *cmd)
{
    uint32_t i = 0;
    
    if(true == ble_fpmm_cmd_buf.receive_flag)
    {
        return;
    }
    if(BLE_FPMM_CMD_BUFFER_SIZE <= len)
    {
        len = BLE_FPMM_CMD_BUFFER_SIZE;
    }
    ble_fpmm_cmd_buf.len = len;
    for(i = 0; i < len; i++)
    {
        ble_fpmm_cmd_buf.buf[i] = ((uint8_t *)cmd)[i];
    }
    ble_fpmm_cmd_buf.receive_flag = true;
}

/*******************************************************************************
* Function Name: InitBle
****************************************************************************//**
*
* \brief Initializes the BLE application.
*
* \param None
*
* \return None
*
*******************************************************************************/
static void InitBle(void)
{
    ble_fpmm_cmd_buf.receive_flag = false;
    ble_app_init(ble_fpmm_command_callback);
}

/*******************************************************************************
* Function Name: BleSend
****************************************************************************//**
*
* \brief Initializes the BLE application.
*
* \param size The size of fpmmm response data
*
* \param pBuff point to the fpmm response data buffer
*
* \return None
*
*******************************************************************************/
static void BleSend(uint32_t size, uint8_t *pBuff)
{
    ble_app_send_fpmm_response(size, pBuff);
}

#if ((CY_BLE_CONFIG_HOST_CORE == CY_BLE_CORE_CORTEX_M0P) || (CY_BLE_STACK_MODE_IPC))
#if defined (__ARMCC_VERSION)
extern void StackRAMInit(uint32_t);
extern void Reset_Handler(void);
/* Variable used to return to the bootloadable when initializing bootloader RAM */
extern uint32_t CyReturnToBootloaddableAddress;
#elif defined (__ICCARM__)
extern void StackRAMInit(void);
#endif /* __ARMCC_VERSION || __ICCARM__ */

#if defined (__ARMCC_VERSION) || (__ICCARM__)
/*******************************************************************************
* Function Name: Cy_OnResetUser()
********************************************************************************
*
* Summary:
*  This function is called at the start of Reset_Handler(). It is a weak function
*  that may be redefined by user code.
*  This function calls BootloaderRAMInit located in the bootloader to initialize
*  the stack's RAM.
*
*******************************************************************************/
void Cy_OnResetUser(void)
{
    #if defined (__ARMCC_VERSION)
    if(CyReturnToBootloaddableAddress == 0)
    {
        StackRAMInit((uint32_t) Reset_Handler);
    }
    CyReturnToBootloaddableAddress = 0;
    #elif defined (__ICCARM__)
    StackRAMInit();
    #endif /* __ARMCC_VERSION || __ICCARM__ */
}
#endif /* __ARMCC_VERSION || __ICCARM__ */
#endif /* ((CY_BLE_CONFIG_HOST_CORE == CY_BLE_CORE_CORTEX_M0P) || (CY_BLE_STACK_MODE_IPC)) */

/* [] END OF FILE */
