/***************************************************************************//**
* \file ble_fpmm_hi.h
* \version 1.0
*
* \brief
* Header file for BLE FPMM (Figerprint Match Module) host interface service.
*
********************************************************************************
* \copyright
* Copyright 2016-2018, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/
#ifndef _BLE_FPMM_HI_H_
#define _BLE_FPMM_HI_H_

#include "ble_common.h"

/* The C binding of definitions if building with the C++ compiler */
#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/***************************************
* Macro definitions
***************************************/
/* Indexes of a two-byte CCCD array */
#define CCCD_INDEX_0            (uint8_t) (0x00u)
#define CCCD_INDEX_1            (uint8_t) (0x01u)

/* Bit mask for the notification bit in CCCD (Client Characteristic Configuration 
   Descriptor), which is written by the client device */
#define CCCD_NOTIFY_ENABLED     (uint8_t) (0x01u)
#define CCCD_NOTIFY_DISABLED    (uint8_t) (0x00u)

/* Redefinition of long CHAR and CCCD handles and indexes for better readability */
#define FPMM_CMD_CHAR_HANDLE (CY_BLE_FPMM_HOST_INTERFACE_FPMM_COMMAND_CHAR_HANDLE)
#define FPMM_CMD_CCCD_HANDLE (CY_BLE_FPMM_HOST_INTERFACE_FPMM_COMMAND_CLIENT_CHARACTERISTIC_CONFIGURATION_DESC_HANDLE)
#define FPMM_CMD_CCCD_INDEX  (CY_BLE_FPMM_HOST_INTERFACE_FPMM_COMMAND_CLIENT_CHARACTERISTIC_CONFIGURATION_DESC_INDEX)
#define FPMM_RES_CHAR_HANDLE (CY_BLE_FPMM_HOST_INTERFACE_FPMM_RESPONSE_CHAR_HANDLE)
#define FPMM_RES_CCCD_HANDLE (CY_BLE_FPMM_HOST_INTERFACE_FPMM_RESPONSE_CLIENT_CHARACTERISTIC_CONFIGURATION_DESC_HANDLE)
#define FPMM_RES_CCCD_INDEX  (CY_BLE_FPMM_HOST_INTERFACE_FPMM_RESPONSE_CLIENT_CHARACTERISTIC_CONFIGURATION_DESC_INDEX)

/* The callback function prototype to handle FPMM command */
typedef void (* ble_fpmm_write_callback_t)(uint32_t len, void *cmd);

/**
 * @brief BLE FPMM command buffer size.
 */
#define BLE_FPMM_CMD_BUFFER_SIZE                            (256u)

/**
 * @brief BLE FPMM response buffer size.
 */
#define BLE_FPMM_RES_BUFFER_SIZE                            (256u)


/***************************************
* Data Types
***************************************/
/* BLE FPMM host interface Configuration structure */
typedef struct
{
    uint8_t res_notification_status;
    ble_fpmm_write_callback_t cmd_callback_func;
    ble_fpmm_write_callback_t res_write_callback_func;
} ble_fpmm_hi_config_t;

/**
 * @brief FPMM command buffer structure for ble command received.
 */
typedef struct
{
    volatile uint8_t receive_flag;
    uint8_t reserve[3];
    uint32_t len;
    uint8_t  buf[BLE_FPMM_CMD_BUFFER_SIZE];
} fpmm_command_buf_t;


/***************************************
* Function Prototypes
***************************************/
cy_en_ble_api_result_t ble_fpmm_hi_init(ble_fpmm_hi_config_t *config);
cy_en_ble_api_result_t ble_fpmm_response_send_notification(cy_stc_ble_conn_handle_t connHandle, uint32_t len, void *res);
cy_en_ble_api_result_t ble_fpmm_hi_write_request_handler(cy_stc_ble_gatts_write_cmd_req_param_t *writeRequest);
cy_en_ble_api_result_t ble_fpmm_response_send_indication(cy_stc_ble_conn_handle_t connHandle, uint16_t attrSize, void *attrValue, uint16_t *actualLen);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* _BLE_FPMM_HI_H_ */

/* [] END OF FILE */
